.. _debops.roundcube:

debops.roundcube
================

The ``debops.roundcube`` Ansible role manages `Roundcube`__, an IMAP Web client
written in PHP.

.. __: https://roundcube.net/

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main
   guides

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.roundcube/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
